/**
* @version      $Id: mod_currency_exchange_informer.js v 1.1
* @package      Currency Exchange Informer
* @copyright    Copyright (C) 2009 FalsinSoft. All rights reserved.
* @license      GNU/GPL
* @website      http://www.falsinsoft.co.nr
* @email        falsinsoft@gmail.com
* 
*/

function CEILoader()
{
	this.id = 0;
	this.RootPath = "";
	this.CurrencyBase = "";
	this.CurrencyConverted = "";
	this.ShowConverterString = "";
	this.HideConverterString = "";
	this.ErrorMessage = "";
	
	this.HttpReq = null;
	this.CurrencyExchangeRate = 0;
};

CEILoader.prototype.CreateXmlHttpReq = function() 
{
	if(this.HttpReq != null) return;
	
    if(window.XMLHttpRequest) 
    {
        this.HttpReq = new XMLHttpRequest();
    } 
    else if(window.ActiveXObject) 
    {
        try 
        {
            this.HttpReq = new ActiveXObject("Msxml2.XMLHTTP");
        } 
        catch(e) 
        {
            try 
            {
                this.HttpReq = new ActiveXObject("Microsoft.XMLHTTP");
            } 
            catch(e) 
            {
                this.HttpReq = null;
            }
        }
    }
};

CEILoader.prototype.ReceiveExchangeRatio = function() 
{
    if(this.HttpReq.readyState == 4) 
    {
        if(this.HttpReq.status == 200)
        {
            var ExchangeRate = parseFloat(this.HttpReq.responseText);
            
            if(isNaN(ExchangeRate) == false && ExchangeRate > 0)
            {
                this.ShowModuleData(ExchangeRate);
            }
            else
            {
                var ConvResDiv = document.getElementById("cei_currency_exchange_rate_"+this.id);
                
                if(ConvResDiv != null)
                {
                     ConvResDiv.innerHTML = "ERROR: loader failed! ("+this.HttpReq.responseText+")";
                } 
            }
        }
    }
};

CEILoader.prototype.ShowModuleData = function(ExchangeRate)
{
    var ConvResDiv   = document.getElementById("cei_currency_exchange_rate_"+this.id);
    var ConvBlockDiv = document.getElementById("cei_converter_block_"+this.id);
    
    if(ConvResDiv != null && ConvBlockDiv != null)
    {
        this.CurrencyExchangeRate = ExchangeRate;

        ConvResDiv.innerHTML = "1 "+this.CurrencyBase+" = <b>"+ExchangeRate+" "+this.CurrencyConverted+"</b>";
                
        ConvBlockDiv.style.display = "block";
    }
};

CEILoader.prototype.ShowLoadingAnimation = function()
{
    var LoadingElement = document.getElementById("cei_currency_exchange_rate_"+this.id)

    if(LoadingElement != null)
    {
        var LoadingAnimation = document.createElement("img");

        LoadingAnimation.setAttribute("src", this.RootPath+"modules/mod_currency_exchange_informer/currency_exchange_loader.gif");
        
        LoadingElement.appendChild(LoadingAnimation);
    }
};

CEILoader.prototype.ShowCurrencyExchangeRate = function(SessionExchangeRate, CallBackFunc)
{
    if(this.CurrencyBase == this.CurrencyConverted)
    {
        var ConvResDiv = document.getElementById("cei_currency_exchange_rate_"+this.id);
                
        if(ConvResDiv != null)
        {
             ConvResDiv.innerHTML = "ERROR: same base and converted currency!";
        }
        
        return;
    }
    
    if(SessionExchangeRate != 0)
    {
        this.ShowModuleData(SessionExchangeRate);
    }
    else
    {
        this.CreateXmlHttpReq();
     
        if(this.HttpReq)
        {
            var LoaderURL = this.RootPath;

            this.ShowLoadingAnimation();
            
            this.HttpReq.onreadystatechange = CallBackFunc;
            
            LoaderURL += "modules/mod_currency_exchange_informer/currency_exchange_loader.php";
            LoaderURL += "?base="+escape(this.CurrencyBase);
            LoaderURL += "&converted="+escape(this.CurrencyConverted);
            LoaderURL += "&rand="+escape(Math.random());
 
            this.HttpReq.open("GET", LoaderURL, true);
            this.HttpReq.send(null);
        }
    }
};

CEILoader.prototype.ShowHideConverter = function()
{
    var ConverterForm  = document.getElementById("cei_converter_form_"+this.id);
    var ConverterLink  = document.getElementById("cei_show_hide_converter_"+this.id);
    
    if(ConverterForm != null && ConverterLink != null)
    {
        if(ConverterForm.style.display == "none")
        {
            ConverterForm.style.display = "block";
            ConverterLink.innerHTML = this.HideConverterString;
        }
        else
        {
            var ValueToConvert = document.getElementById("cei_value_to_convert_"+this.id);
            var ConvertedValue = document.getElementById("cei_converted_value_"+this.id);
            
            ConverterForm.style.display = "none";
            ConverterLink.innerHTML = this.ShowConverterString;
            
            if(ValueToConvert != null && ConvertedValue != null)
            {
                ValueToConvert.value = "";
                ConvertedValue.innerHTML = "";
            }
        }
    }
};

CEILoader.prototype.SetConversionCurrencyBase = function(SetCurrencyBase)
{
    var ConversionCurrencyBase = document.getElementById("cei_conversion_currency_base_"+this.id);

    if(ConversionCurrencyBase != null)
    {
        ConversionCurrencyBase.innerHTML = (SetCurrencyBase == true) ? this.CurrencyBase : this.CurrencyConverted;
    }
};

CEILoader.prototype.ConvertValue = function()
{
    if(this.CurrencyExchangeRate > 0)
    {
        var ValueToConvert          = document.getElementById("cei_value_to_convert_"+this.id);
        var ConvertedValue          = document.getElementById("cei_converted_value_"+this.id);
        var SelectionBaseRadio      = document.getElementById("cei_selection_base_radio_"+this.id);
        var SelectionConvertedRadio = document.getElementById("cei_selection_converted_radio_"+this.id);
        
        if(ValueToConvert != null && ConvertedValue != null && SelectionBaseRadio != null && SelectionConvertedRadio != null)
        {
            var ConversionResult, ValueBase;

            if(ValueToConvert.value.trim() == "" || isNaN(ValueToConvert.value) == true || parseFloat(ValueToConvert.value) == 0)
            {
                ConvertedValue.innerHTML = this.ErrorMessage;
                return;
            }
            
            ValueBase = parseFloat(ValueToConvert.value);
            
            if(SelectionBaseRadio.checked == true)
            {
                ConversionResult = eval(ValueBase * this.CurrencyExchangeRate);
                ConvertedValue.innerHTML = ValueBase+" "+this.CurrencyBase+" = <b>"+this.RoundNumber(ConversionResult, 4)+" "+this.CurrencyConverted+"</b>";
            }
            else
            {
                ConversionResult = eval(ValueBase / this.CurrencyExchangeRate);
                ConvertedValue.innerHTML = ValueBase+" "+this.CurrencyConverted+" = <b>"+this.RoundNumber(ConversionResult, 4)+" "+this.CurrencyBase+"</b>";
            }
        }
    }
};

CEILoader.prototype.RoundNumber = function(Number, MaxDecimals) 
{
    var StrNum, DotPos, Decimals, Exponent, RoundedNum, NumPos, NumChar;

    StrNum = Number.toString();
    
    DotPos = StrNum.indexOf(".");
    
    if(DotPos == -1) return Number;

    Decimals = (StrNum.length - DotPos - 1);

    if(Decimals > MaxDecimals) Decimals = MaxDecimals;

    Exponent = Math.pow(10, Decimals);

    RoundedNum = (Math.round(Number * Exponent) / Exponent);

    StrNum = RoundedNum.toString();

    DotPos = StrNum.indexOf(".");

    if(DotPos != -1)
    {
        for(NumPos = (StrNum.length - 1); NumPos > 0; NumPos--)
        {
            NumChar = StrNum.charAt(NumPos);
            
            if(NumChar != "0" || NumChar == ".") break;
            
            StrNum = StrNum.substr(0, NumPos);
        }
        
        RoundedNum = parseFloat(StrNum)
    }

    return RoundedNum;
};
